<?php
/*--------------------------------------------------*/
/* File Created by ibProArcade 3.x.x!				*/
/* File Generated: Fri, 15 Jan 2016 09:44:12 GMT	*/
/*--------------------------------------------------*/

$config = array(
	'active'			=> '1',
	'bgcolor'			=> '000000',
	'gcat'			=> '13',
	'gheight'			=> '600',
	'gkeys'			=> 'Mouse',
	'gname'			=> 'AlterEggoAS3v2DOT',
	'gtitle'			=> 'Alter Eggo',
	'gwidth'			=> '755',
	'gwords'			=> 'On the far off planet of Ducktoran, the deities have gathered for the annual Hatching of the Eggs. This year, Lemmy the Llama has offered to babysit the eggs while everyone attends the Great Feast. All he has to do is keep them warm for the next few days. But Lemmy is not the brightest God in the universe, places the eggs in mega hot Jelly geysers and before he knows it the eggs are spread all over the skies and covered in Jelly&#33; Help Lemmy clear the hot Jelly under the eggs by creating matches. When all the Jelly has been removed from the board, the area is safe and you may proceed to the next level. Give Lemmy a hand to round up the new Ducktoran babies before the feast is over. Ready, steady, quack&#33;',
	'highscore_type'			=> 'high',
	'object'			=> 'Click on an egg to switch it&#39;s color....Match 3 or more adjacent same color eggs to Clear all the jelly&#39;s to finish a level..',
	'snggame'			=> '0',
);
?>